@@ -3,14 +3,14 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 sub ident_plain {
-    'h2c'
+    'h2c';
 }
 
 sub ident_tls {
-    'h2'
+    'h2';
 }
 
 1;
